@@ -6,7 +6,7 @@
 #' @param sig_level Significance level to determine statistically significant seasonal frequencies
 #' @param prior A data table created by stsm_prior
 #' @import data.table
-#' @return String of trend type
+#' @return list with trend type and logical flag for deterministic trend if the trend is determined to have 0 differencing
 #' @examples
 #' \dontrun{
 #' #GDP Not seasonally adjusted
@@ -33,7 +33,7 @@ stsm_detect_trend = function(y, freq, decomp = "", sig_level = 0.01, prior = NUL
   ol = forecast::tsoutliers(stats::ts(prior$seasonal_adj, frequency = freq))
   prior[ol$index, "seasonal_adj" := ol$replacements]
   #Test for a trend
-  trend_test = (tsutils::coxstuart(prior$seasonal_adj, type = "trend")$p.value <= sig_level)
+  trend_test = (tsutils::coxstuart(stats::na.omit(prior$seasonal_adj), type = "trend")$p.value <= sig_level)
   ndiffs = sapply(c("adf", "pp", "kpss"), function(x){forecast::ndiffs(prior$seasonal_adj, type = "level", alpha = sig_level, max.d = 2)})
   #Find the most agreed upon differences
   ndiffs = data.table(ndiffs)[, .N, by = "ndiffs"]
@@ -43,19 +43,15 @@ stsm_detect_trend = function(y, freq, decomp = "", sig_level = 0.01, prior = NUL
   ndiffs = ifelse(1 %in% ndiffs$ndiffs, 1,
                   ifelse(2 %in% ndiffs$ndiffs, 2, 
                          ndiffs[1, ]$ndiffs))
-  if(ndiffs == 2){
+  if(ndiffs >= 2){
     trend = "double-random-walk"
   }else if((ndiffs == 1) & trend_test == TRUE){
     trend = "random-walk-drift"
   }else if((ndiffs == 1) & trend_test == FALSE){
     trend = "random-walk"
-  }else if(ndiffs == 0 & trend_test == TRUE){
-    trend = "random-walk-drift"
-  }else if(ndiffs == 0 & trend_test == FALSE){
+  }else if(ndiffs == 0){
     trend = "random-walk"
-  }else{
-    stop("ndiffs in trend detection was not 0, 1, or 2.")
   }
   
-  return(trend)
+  return(list(trend = trend, det_trend = (ndiffs == 0)))
 }
